#ifndef __INCTestFlashh
#define __INCTestFlashh

#define TESTFLASH_API(T) T _stdcall

/* Return codes */
#define TFL_OK 0
#define TFL_ERROR -1

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*************************************************************************************
	
	Function Name :	int flInit(int port, int xtal, int delats);

	Parameters :
					port - Number refering to the LPT port to be used

					xtal - specifies module's crystal frequency. Acceptable values are 
						10, 16, 26, 32. Higner values make code run slower, lower 
						values may cause instability. (Casiras use 16Mhz).

					delays - delay used in driving the SPI port.  1 = fastest SPI 
						speed, but may give unreliablilty.
						2 = reasonable value,
						higer values may be better if chip is in deep sleep.
	

	Returns :		non-zero on failure, 0 on success.

	Description :	This function is used to create the appropriate host side objects 
					to enable flash programming via the SPI or gang programming 
					interface.<br>
					No communication with BlueCore is carried out

*************************************************************************************/
TESTFLASH_API(int) flInit(int port, int xtal, int delays);

/*************************************************************************************
	
	Function Name :	int flReadProgramFiles(char * filename);

	Parameters :
					filename - string containing the directory and filename root. This
						function will generate the XPV and XDV extensions.

	Returns :		non-zero on failure, 0 on success.

	Description :	This function is used to load the firmware files into memory.

*************************************************************************************/
TESTFLASH_API(int) flReadProgramFiles(char * filename);

/*************************************************************************************
	
	Function Name :	int flProgramBlock(void);

	Parameters :	
                    none

	Returns :		0 on success, non-zero on failure where:
                        <table>
						<tr><td>FLASH_ERROR_NONE                    <td> 0
						<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
						<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
						<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
						<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
						<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
						<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
						<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
						<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
						<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
						<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
                        </table>

	Description :	This function is used to download the firmware to the device under 
					test. The function will block until the process has completed 
					successfully or an error occurs.

*************************************************************************************/
TESTFLASH_API(int) flProgramBlock(void);

/*************************************************************************************
	
  Function Name : int flErase(void)

  Parameters :	
                  none

  Returns :		  0 on success, non-zero on failure where:
                    <table>
					<tr><td>FLASH_ERROR_NONE                    <td> 0
					<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
					<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
					<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
					<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
					<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
					<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
					<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
					<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
					<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
					<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
                    </table>

  Description :	  This function is used to erase the flash.

*************************************************************************************/
TESTFLASH_API(int) flErase(void);

/*************************************************************************************
	
	Function Name :	int flGangProgramBlock(unsigned short device_mask, char eraseFirst, char restartAfter);

	Parameters :	
                    device_mask - Specifies which devices will be programmed. Uses a 
						bit-field so 5 = 0000000000000101 = devices 0 and 2. A value 
						of 0 (zero) will auto-detect and programme all devices present.

					eraseFirst - will erase the entire flash of all devices before 
						programming.

					restartAfter - will restart the XAP after completion of the flash process

	Returns :		0 on success, non-zero on failure where:
                        <table>
						<tr><td>FLASH_ERROR_NONE                    <td> 0
						<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
						<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
						<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
						<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
						<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
						<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
						<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
						<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
						<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
						<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
						<tr><td>FLASH_ERROR_UNKNOWN_CHIP_TYPE       <td> 11
						<tr><td>FLASH_ERROR_BROADCAST_MIXED_CHIP_TYPES <td> 12
                        </table>
					
					If all the specified devices were programmed correctly the function 
					will return FLASH_ERROR_NONE, if there were 1 or more programming 
					failures then the function will return 
					FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG. All other error returns denote 
					a gross failure.

	Description :	This function is used to download the firmware to up to 16 devices 
					when using the gang programmer reference device. This function 
					will block execution until the process completes successfully or 
					an error occurs.

					On completion with an error return of either FLASH_ERROR_NONE or 
					FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG the programmer should call 
					get_bit_error_field() to determine which device has failed to 
					programmme correctly.

*************************************************************************************/
TESTFLASH_API(int) flGangProgramBlock(unsigned short device_mask, char eraseFirst, char restartAfter);

/*************************************************************************************
	
	Function Name :	unsigned short flGetBitErrorField(void);

	Parameters :	
                    none

	Returns :		Bitfield refering to the devices present on the gang programmer 
					and those that have failed. Will return (failed_devices & device_mask). 
					Therefore a return of zero (0) means all devices have been 
					programmed successfully. A return value of five (5) denotes that 
					devices 0 and 2 have failed and the remainder have successfully 
					been programmed.

	Description :	This function is used to determine which devices have failed to be 
					programmed during the gang_programming process.

*************************************************************************************/
TESTFLASH_API(unsigned short) flGetBitErrorField(void);

/*************************************************************************************
	
	Function Name :	int flProgramSpawn(void);

	Parameters :	none

	Returns :		
                    0 on success, non-zero on failure where:
                        <table>
						<tr><td>FLASH_ERROR_NONE                    <td> 0
						<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
						<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
						<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
						<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
						<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
						<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
						<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
						<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
						<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
						<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
                        </table>

	Description :	This function is used to download the firmware to the device under 
					test. The function will spawn the process which performs the flash 
					programming. The programmer can then use further functions to 
					check the progress and to retrieve the final error code.

*************************************************************************************/
TESTFLASH_API(int) flProgramSpawn(void);

/*************************************************************************************
	
	Function Name :	int flGangProgramSpawn(unsigned short device_mask, char eraseFirst, char restartAfter)

	Parameters :	
                    device_mask - Specifies which devices will be programmed. Uses a 
						bit-field so 5 = 0000000000000101 = devices 0 and 2. A value 
						of 0 (zero) will auto-detect and programme all devices present.

					eraseFirst - will erase the entire flash of all devices before 
						programming.

					restartAfter - will restart the XAP after completion of the flash process


	Returns :
                    0 on success, non-zero on failure where:
                        <table>
						<tr><td>FLASH_ERROR_NONE                    <td> 0
						<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
						<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
						<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
						<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
						<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
						<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
						<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
						<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
						<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
						<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
                        </table>

	Description :	This function is used to download the firmware to the device under 
					test. The function will spawn the process which performs the flash 
					programming. The programmer can then use further functions to 
					check the progress and to retrieve the final error code.

*************************************************************************************/
TESTFLASH_API(int) flGangProgramSpawn(unsigned short device_mask, char eraseFirst, char restartAfter);


/*************************************************************************************
	
	Function Name :	int flGetProgress(void);

	Parameters :	
                    none

	Returns :		Progress so far in the range 0 to 100. Where 100 indicates the 
					spawned programming process has returned with or without an error.

	Description :	This function is used to check the progress of the process spawned 
					by program_flash_spawn().

*************************************************************************************/
TESTFLASH_API(int) flGetProgress(void);

/*************************************************************************************
	
	Function Name :	int flGetLastError(void);

	Parameters :	none

	Returns :		0 on success, non-zero on failure where:
                        <table>
						<tr><td>FLASH_ERROR_NONE                    <td> 0
						<tr><td>FLASH_ERROR_DOWNLOAD_FAILED         <td> 1
						<tr><td>FLASH_ERROR_VERIFY_FAILED           <td> 2
						<tr><td>FLASH_ERROR_TIMED_OUT               <td> 3
						<tr><td>FLASH_ERROR_CRC_FAILED              <td> 4
						<tr><td>FLASH_ERROR_READBACK_FAILED         <td> 5
						<tr><td>FLASH_ERROR_COULD_NOT_DOWNLOAD_PROG <td> 6
						<tr><td>FLASH_ERROR_COULD_NOT_STOP_XAP      <td> 7
						<tr><td>FLASH_ERROR_BOOT_PROG_HALTED        <td> 8
						<tr><td>FLASH_ERROR_ERASE_FAILED            <td> 9
						<tr><td>FLASH_ERROR_XAP_ERROR               <td> 10
                        </table>

	Description :	This function will return the last error generated by the flash 
					programming stack. If called after get_spawned_progress() returns 
					100 it can be used to check for programming errors.

*************************************************************************************/
TESTFLASH_API(int) flGetLastError(void);

/*************************************************************************************
	
  Function Name : int flResetAndStart(void);

  Parameters :	
                  none

  Returns :		  0 on success, -1 on failure

  Description :	  This function is used to reset the device after the spawned 
                  programming funtion has completed.

*************************************************************************************/
TESTFLASH_API(int) flResetAndStart(void);

/*************************************************************************************
	
	Function Name :	void flClose(void);

	Parameters :	
                    none

	Returns :		none

	Description :	Deletes all the memory associated with the flash programming 
					process.

*************************************************************************************/
TESTFLASH_API(void) flClose(void);

/*************************************************************************************
	
	Function Name :	void flGetVersion(char * versionStr);

	Parameters :	
                    versionStr - Pre-allocated string for receiving version number.

	Returns :		Version string for this DLL.

	Description :	Returns the version string for this DLL.

*************************************************************************************/
TESTFLASH_API(int) flGetVersion(char * versionStr);

/*******************************************************************************
  
  Function Name : int flStopProcessor(void)

  Parameters :	  none.

  Returns :		  0 if processor stopped successfully, otherwise -1.

  Description :	  This function will stop the processor on the current SPI
                  connection.<br>
                  A valid SPI connection has to be made using the flInit
                  function for this function to complete successfully.

*******************************************************************************/
TESTFLASH_API(int) flStopProcessor(void);

/* DEPRECATED_START */
#define init_flash               flInit
#define read_program_files       flReadProgramFiles
#define program_flash_block      flProgramBlock
#define erase_flash              flErase
#define gang_program_flash_block flGangProgramBlock
#define get_bit_error_field      flGetBitErrorField
#define program_flash_spawn      flProgramSpawn
#define gang_program_flash_spawn flGangProgramSpawn
#define get_spawned_progress     flGetProgress
#define get_spawned_error        flGetLastError
#define reset_and_start          flResetAndStart
#define close_flash              flClose
#define get_version              flGetVersion
/* DEPRECATED_END */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __INCTestFlashh */
